searchData={"items":[{"type":"module","title":"Mozart.Data.ProcessModel","doc":"```\ndefstruct [:name, :tasks, :initial_task]\n```\n\nThis struct is used to create business process models. Once created, a process model\ncan be loaded into a `Mozart.ProcessEngine.html` and executed.\n\nAlso see Mozart.Task modules.\n\nExample:\n\n```\n%ProcessModel{\n      name: :user_task_process_model,\n      tasks: [\n        %User{\n          name: :user_task,\n          assigned_groups: [\"admin\"]\n        }\n      ],\n      initial_task: :user_task\n    }\n```","ref":"Mozart.Data.ProcessModel.html"},{"type":"module","title":"Mozart.Data.ProcessState","doc":"```\ndefstruct [\n    :uid,\n    :parent,\n    :model_name,\n    :start_time,\n    :end_time,\n    :execute_duration,\n    open_tasks: %{},\n    completed_tasks: [],\n    data: %{},\n    complete: false\n  ]\nend\n```\n\nThis struct is used to represent the state of a `Mozart.ProcessEngine` execution.\n\nExample: (incrementally populated throughout process execution.)\n\n```\n%Mozart.Data.ProcessState{\n  uid: \"74146e68-088e-42b6-965e-20f4d7dbae16\",\n  parent: nil,\n  model_name: :call_external_service,\n  start_time: ~U[2024-05-27 15:22:01.847683Z],\n  end_time: ~U[2024-05-27 15:22:02.277273Z],\n  execute_duration: 429590,\n  open_tasks: %{},\n  completed_tasks: [\n    %{\n      data: %{},\n      function: #Function<0.23164178/1 in Mozart.ProcessModels.TestModels.call_exteral_services/0>,\n      name: :get_api_data,\n      type: :service,\n      next: nil,\n      __struct__: Mozart.Task.Service,\n      uid: \"e3326041-d203-46b2-8141-907f71421398\",\n      process_uid: \"74146e68-088e-42b6-965e-20f4d7dbae16\"\n    }\n  ],\n  data: %{\n    todo_data: %{\n      \"completed\" => false,\n      \"id\" => 1,\n      \"title\" => \"delectus aut autem\",\n      \"userId\" => 1\n    }\n  },\n  complete: true\n}\n```","ref":"Mozart.Data.ProcessState.html"},{"type":"module","title":"Mozart.ProcessEngine","doc":"A ProcessEngine is dynamically spawned for the purpose of executing a `Mozart.Data.ProcessModel`.","ref":"Mozart.ProcessEngine.html"},{"type":"function","title":"Mozart.ProcessEngine.execute/1","doc":"Used to complete any \"complete-able\" open tasks. Task execution frequently spawns new\nopen tasks. Execute will continue to as long as there are \"complete-able\" open tasks.\n\nNote: Some types of task are completeable immediately and some are not. For\nexample:\n  * A `Mozart.Task.Service` task is complete-able as soon as it is opened.\n  * A `Mozart.Task.User` task when a user completes the task.\n  * A `Mozart.Task.Receive` task is complete-able when a matching\n    `Mozart.Task.Send` task is received.","ref":"Mozart.ProcessEngine.html#execute/1"},{"type":"function","title":"Mozart.ProcessEngine.start_process/3","doc":"Use this function to create a ProcessEngine instance initialized with the\nname of the process model to be executed and any initialization data. The\nengine will start executing tasks with the execute/1 function is called.","ref":"Mozart.ProcessEngine.html#start_process/3"},{"type":"module","title":"Mozart.ProcessModelService","doc":"Acts as a reposatory for storing and retreiving `Mozart.Data.ProcessModel`","ref":"Mozart.ProcessModelService.html"},{"type":"function","title":"Mozart.ProcessModelService.get_process_model/1","doc":"Retrieves a process model by name.","ref":"Mozart.ProcessModelService.html#get_process_model/1"},{"type":"function","title":"Mozart.ProcessModelService.load_process_model/1","doc":"Loads a single process model in the repository.","ref":"Mozart.ProcessModelService.html#load_process_model/1"},{"type":"function","title":"Mozart.ProcessModelService.load_process_models/1","doc":"Loads a list of `Mozart.Data.ProcessModel`s into the state of the\nProcessModelService.","ref":"Mozart.ProcessModelService.html#load_process_models/1"},{"type":"module","title":"Mozart.ProcessService","doc":"This modeule provides services required by individual `Mozart.ProcessEngine` instances. Currently,\nit has no user level functions. Subject to change.","ref":"Mozart.ProcessService.html"},{"type":"module","title":"Mozart.Task.Choice","doc":"Used to define a process model Choice Task. Serves the same purpose as a BPMN2 Exclusive Gate.\nThe **choices** field is used to specify the multiple execution paths.\n\nExample:\n```\n%ProcessModel{\n      name: :choice_process_model,\n      tasks: [\n        %Choice{\n          name: :choice_task,\n          choices: [\n            %{\n              expression: fn data -> data.value < 10 end,\n              next: :foo\n            },\n            %{\n              expression: fn data -> data.value >= 10 end,\n              next: :bar\n            }\n          ]\n        }\n      ],\n      initial_task: :choice_task\n    }\n```","ref":"Mozart.Task.Choice.html"},{"type":"module","title":"Mozart.Task.Decision","doc":"Used to model a Mozart decision task. Called a Business Rule in BPMN2. Uses\nthe Elixir [tablex](https://hex.pm/packages/tablex) library.\n\nExample:\n\n```\n%ProcessModel{\n      name: :load_approval,\n      tasks: [\n        %Decision{\n          name: :loan_decision,\n          decision_args: :loan_args,\n          tablex:\n            Tablex.new(\"\"\"\n            F     income      || status\n            1     > 50000     || approved\n            2     <= 49999    || declined\n            \"\"\"),\n        },\n      ],\n      initial_task: :loan_decision\n    }\n```","ref":"Mozart.Task.Decision.html"},{"type":"module","title":"Mozart.Task.Join","doc":"Used to join parallel execution paths.\n\nExample:\n\n```\n%ProcessModel{\n      name: :parallel_process_model,\n      tasks: [\n        %Parallel{\n          name: :parallel_task,\n          multi_next: [:foo, :bar]\n        },\n        %Service{\n          name: :foo,\n          function: fn data -> Map.merge(data, %{foo: :foo}) end,\n          next: :join_task\n        },\n        %Service{\n          name: :bar,\n          function: fn data -> Map.merge(data, %{bar: :bar}) end,\n          next: :foo_bar\n        },\n        %Service{\n          name: :foo_bar,\n          function: fn data -> Map.merge(data, %{foo_bar: :foo_bar}) end,\n          next: :join_task\n        },\n        # Here's the Join task. Must receive all inputs before completing.\n        %Join{\n          name: :join_task,\n          inputs: [:foo, :foo_bar],\n          next: :final_service\n        },\n        %Service{\n          name: :final_service,\n          function: fn data -> Map.merge(data, %{final: :final}) end\n        }\n      ],\n      initial_task: :parallel_task\n    }\n```","ref":"Mozart.Task.Join.html"},{"type":"module","title":"Mozart.Task.Parallel","doc":"Use to create paralled execution paths.\n\nExample:\n\n```\n%ProcessModel{\n      name: :parallel_process_model,\n      tasks: [\n        # Here is the parallel task. Both :foo and :bar start paralled paths\n        %Parallel{\n          name: :parallel_task,\n          multi_next: [:foo, :bar]\n        },\n        %Service{\n          name: :foo,\n          function: fn data -> Map.merge(data, %{foo: :foo}) end,\n          next: :join_task\n        },\n        %Service{\n          name: :bar,\n          function: fn data -> Map.merge(data, %{bar: :bar}) end,\n          next: :foo_bar\n        },\n        %Service{\n          name: :foo_bar,\n          function: fn data -> Map.merge(data, %{foo_bar: :foo_bar}) end,\n          next: :join_task\n        },\n        %Join{\n          name: :join_task,\n          inputs: [:foo, :foo_bar],\n          next: :final_service\n        },\n        %Service{\n          name: :final_service,\n          function: fn data -> Map.merge(data, %{final: :final}) end\n        }\n      ],\n      initial_task: :parallel_task\n    }\n```","ref":"Mozart.Task.Parallel.html"},{"type":"module","title":"Mozart.Task.Receive","doc":"Used to model a task that waits for a PubSub message. Functional but needs\nsome work.\n\nExample:\n\n```\n%ProcessModel{\n      name: :process_with_receive_task,\n      tasks: [\n        %Receive{\n          name: :receive_task,\n          message_selector: fn msg ->\n            case msg do\n              :message -> %{message: true}\n              _ -> false\n            end\n          end\n        }\n      ],\n      initial_task: :receive_task\n    },\n    %ProcessModel{\n      name: :process_with_single_send_task,\n      tasks: [\n        %Send{\n          name: :send_task,\n          message: :message\n        },\n      ],\n      initial_task: :send_task\n    }\n```","ref":"Mozart.Task.Receive.html"},{"type":"module","title":"Mozart.Task.Send","doc":"Used to send a PubSub message to a waiting Receive task. Functioal but needs\nsome work.\n\nExample:\n\n```\n%ProcessModel{\n      name: :process_with_receive_task,\n      tasks: [\n        %Receive{\n          name: :receive_task,\n          message_selector: fn msg ->\n            case msg do\n              :message -> %{message: true}\n              _ -> false\n            end\n          end\n        }\n      ],\n      initial_task: :receive_task\n    },\n    %ProcessModel{\n      name: :process_with_single_send_task,\n      tasks: [\n        %Send{\n          name: :send_task,\n          message: :message\n        },\n      ],\n      initial_task: :send_task\n    }\n```","ref":"Mozart.Task.Send.html"},{"type":"module","title":"Mozart.Task.Service","doc":"Used to model a Service task. A service task calls a function and returns\ndata that is into the state data.\n\nExample:\n\n```\n%ProcessModel{\n      name: :process_with_single_service_task,\n      tasks: [\n        %Service{\n          name: :service_task,\n          function: fn data -> Map.merge(data, %{single_service: true}) end\n        }\n      ],\n      initial_task: :service_task\n    }\n```","ref":"Mozart.Task.Service.html"},{"type":"function","title":"Mozart.Task.Service.__struct__/0","doc":"","ref":"Mozart.Task.Service.html#__struct__/0"},{"type":"module","title":"Mozart.Task.Subprocess","doc":"Used to model a task that is completed by executing and completing a\nsubprocess. Called a **call activity** in BPMN2.\n\nExample:\n\n```\n%ProcessModel{\n      name: :call_process_model,\n      tasks: [\n        %Subprocess{\n          name: :call_process_task,\n          sub_process: :service_subprocess_model,\n          next: :service_task1\n        },\n        %Service{\n          name: :service_task1,\n          function: fn data -> Map.put(data, :value, data.value + 1) end\n        }\n      ],\n      initial_task: :call_process_task\n    },\n    %ProcessModel{\n      name: :service_subprocess_model,\n      tasks: [\n        %Service{\n          name: :service_task,\n          function: fn data -> Map.put(data, :subprocess_data, \"subprocess data\") end\n        }\n      ],\n      initial_task: :service_task\n    }\n```","ref":"Mozart.Task.Subprocess.html"},{"type":"module","title":"Mozart.Task.Timer","doc":"Used to model a task waits a specified duration and automatically completes.\n\nExample:\n\n```\n%ProcessModel{\n    name: :call_timer_task,\n    tasks: [\n      %Timer{\n        name: :wait_1_seconds,\n        timer_duration: 10\n      },\n    ],\n    initial_task: :wait_1_seconds\n  }\n```","ref":"Mozart.Task.Timer.html"},{"type":"module","title":"Mozart.Task.User","doc":"Used to model a task that must be completed by a system user.\n\nExample:\n\n```\n%ProcessModel{\n      name: :user_task_process_model,\n      tasks: [\n        %User{\n          name: :user_task,\n          assigned_groups: [\"admin\"]\n        }\n      ],\n      initial_task: :user_task\n    }\n```","ref":"Mozart.Task.User.html"},{"type":"module","title":"Mozart.UserService","doc":"Provides client applications with functionality related to users and groups. Much more\nfunctionality to come.","ref":"Mozart.UserService.html"},{"type":"function","title":"Mozart.UserService.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Mozart.UserService.html#child_spec/1"},{"type":"function","title":"Mozart.UserService.get_assigned_groups/1","doc":"Returns the groups that a user is a member of.","ref":"Mozart.UserService.html#get_assigned_groups/1"},{"type":"function","title":"Mozart.UserService.get_user/1","doc":"Given a user id, return detailed user info.","ref":"Mozart.UserService.html#get_user/1"},{"type":"function","title":"Mozart.UserService.insert_user/1","doc":"Adds a new user to the system.","ref":"Mozart.UserService.html#insert_user/1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}